The functions plot the CDF, PDF and QQ-plot of a fitted distribution object together with the empirical values.
autoplot.comp_fit(x, which = "all", layout = matrix(c(1, 2, 1, 3), nrow
= 2), empir_color = "#F9D607", empir_alpha = 0.4, ...)distribution object.
whether to plot only CDF, PDF, qq or all three, default: 'all'.
layout of plots, default: matrix(c(1, 2, 1, 3), nrow = 2).
color of empirical data, default: '#F9D607'.
alpha of empirical data, default: 0.4.
further arguments to be passed.
ggplot object if which = "cdf" or which = "pdf" or which = "qq".
If all are plotted, the plots are merged using multiplot() function and a list with all plots is invisibly returned.